summaryrefslogtreecommitdiff
path: root/src/bin
diff options
context:
space:
mode:
Diffstat (limited to 'src/bin')
-rw-r--r--src/bin/initdb/initdb.c2
-rw-r--r--src/bin/pg_archivecleanup/pg_archivecleanup.c4
-rw-r--r--src/bin/pg_basebackup/pg_basebackup.c2
-rw-r--r--src/bin/pg_basebackup/pg_receivewal.c2
-rw-r--r--src/bin/pg_basebackup/pg_recvlogical.c2
-rw-r--r--src/bin/pg_config/pg_config.c2
-rw-r--r--src/bin/pg_controldata/pg_controldata.c2
-rw-r--r--src/bin/pg_ctl/pg_ctl.c2
-rw-r--r--src/bin/pg_dump/pg_dump.c2
-rw-r--r--src/bin/pg_dump/pg_dumpall.c2
-rw-r--r--src/bin/pg_dump/pg_restore.c2
-rw-r--r--src/bin/pg_resetwal/pg_resetwal.c2
-rw-r--r--src/bin/pg_rewind/pg_rewind.c2
-rw-r--r--src/bin/pg_upgrade/option.c2
-rw-r--r--src/bin/pg_verify_checksums/pg_verify_checksums.c2
-rw-r--r--src/bin/pgbench/pgbench.c2
-rw-r--r--src/bin/psql/help.c2
-rw-r--r--src/bin/scripts/clusterdb.c2
-rw-r--r--src/bin/scripts/createdb.c2
-rw-r--r--src/bin/scripts/createuser.c2
-rw-r--r--src/bin/scripts/dropdb.c2
-rw-r--r--src/bin/scripts/dropuser.c2
-rw-r--r--src/bin/scripts/pg_isready.c2
-rw-r--r--src/bin/scripts/reindexdb.c2
-rw-r--r--src/bin/scripts/vacuumdb.c2
25 files changed, 26 insertions, 26 deletions
diff --git a/src/bin/initdb/initdb.c b/src/bin/initdb/initdb.c
index e55ba668ce..fd50a809ea 100644
--- a/src/bin/initdb/initdb.c
+++ b/src/bin/initdb/initdb.c
@@ -2419,7 +2419,7 @@ usage(const char *progname)
printf(_(" -?, --help show this help, then exit\n"));
printf(_("\nIf the data directory is not specified, the environment variable PGDATA\n"
"is used.\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
static void
diff --git a/src/bin/pg_basebackup/pg_basebackup.c b/src/bin/pg_basebackup/pg_basebackup.c
index e51ef91d66..594d67c9e9 100644
--- a/src/bin/pg_basebackup/pg_basebackup.c
+++ b/src/bin/pg_basebackup/pg_basebackup.c
@@ -377,7 +377,7 @@ usage(void)
printf(_(" -U, --username=NAME connect as specified database user\n"));
printf(_(" -w, --no-password never prompt for password\n"));
printf(_(" -W, --password force password prompt (should happen automatically)\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_basebackup/pg_receivewal.c b/src/bin/pg_basebackup/pg_receivewal.c
index dc6705c330..aa114f1563 100644
--- a/src/bin/pg_basebackup/pg_receivewal.c
+++ b/src/bin/pg_basebackup/pg_receivewal.c
@@ -103,7 +103,7 @@ usage(void)
printf(_("\nOptional actions:\n"));
printf(_(" --create-slot create a new replication slot (for the slot's name see --slot)\n"));
printf(_(" --drop-slot drop the replication slot (for the slot's name see --slot)\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
static bool
diff --git a/src/bin/pg_basebackup/pg_recvlogical.c b/src/bin/pg_basebackup/pg_recvlogical.c
index d75b66f1e7..10429a529d 100644
--- a/src/bin/pg_basebackup/pg_recvlogical.c
+++ b/src/bin/pg_basebackup/pg_recvlogical.c
@@ -105,7 +105,7 @@ usage(void)
printf(_(" -U, --username=NAME connect as specified database user\n"));
printf(_(" -w, --no-password never prompt for password\n"));
printf(_(" -W, --password force password prompt (should happen automatically)\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
/*
diff --git a/src/bin/pg_config/pg_config.c b/src/bin/pg_config/pg_config.c
index 6b119be9d7..5279e7fd79 100644
--- a/src/bin/pg_config/pg_config.c
+++ b/src/bin/pg_config/pg_config.c
@@ -102,7 +102,7 @@ help(void)
printf(_(" --version show the PostgreSQL version\n"));
printf(_(" -?, --help show this help, then exit\n"));
printf(_("\nWith no arguments, all known items are shown.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
static void
diff --git a/src/bin/pg_controldata/pg_controldata.c b/src/bin/pg_controldata/pg_controldata.c
index 895a51f89d..1e1fd85b0b 100644
--- a/src/bin/pg_controldata/pg_controldata.c
+++ b/src/bin/pg_controldata/pg_controldata.c
@@ -40,7 +40,7 @@ usage(const char *progname)
printf(_(" -?, --help show this help, then exit\n"));
printf(_("\nIf no data directory (DATADIR) is specified, "
"the environment variable PGDATA\nis used.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_ctl/pg_ctl.c b/src/bin/pg_ctl/pg_ctl.c
index 24caa6fca5..c82a702ffa 100644
--- a/src/bin/pg_ctl/pg_ctl.c
+++ b/src/bin/pg_ctl/pg_ctl.c
@@ -2084,7 +2084,7 @@ do_help(void)
printf(_(" demand start service on demand\n"));
#endif
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_dump/pg_dump.c b/src/bin/pg_dump/pg_dump.c
index 0e129f9654..2b1a94733b 100644
--- a/src/bin/pg_dump/pg_dump.c
+++ b/src/bin/pg_dump/pg_dump.c
@@ -997,7 +997,7 @@ help(const char *progname)
printf(_("\nIf no database name is supplied, then the PGDATABASE environment\n"
"variable value is used.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
static void
diff --git a/src/bin/pg_dump/pg_dumpall.c b/src/bin/pg_dump/pg_dumpall.c
index 1d539193ca..5d40d19596 100644
--- a/src/bin/pg_dump/pg_dumpall.c
+++ b/src/bin/pg_dump/pg_dumpall.c
@@ -643,7 +643,7 @@ help(void)
printf(_("\nIf -f/--file is not used, then the SQL script will be written to the standard\n"
"output.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_dump/pg_restore.c b/src/bin/pg_dump/pg_restore.c
index 44012ff44d..428e040acb 100644
--- a/src/bin/pg_dump/pg_restore.c
+++ b/src/bin/pg_dump/pg_restore.c
@@ -520,5 +520,5 @@ usage(const char *progname)
"The options -I, -n, -N, -P, -t, -T, and --section can be combined and specified\n"
"multiple times to select multiple objects.\n"));
printf(_("\nIf no input file name is supplied, then standard input is used.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_resetwal/pg_resetwal.c b/src/bin/pg_resetwal/pg_resetwal.c
index e3213d404a..562c27904f 100644
--- a/src/bin/pg_resetwal/pg_resetwal.c
+++ b/src/bin/pg_resetwal/pg_resetwal.c
@@ -1325,5 +1325,5 @@ usage(void)
printf(_(" -x, --next-transaction-id=XID set next transaction ID\n"));
printf(_(" --wal-segsize=SIZE size of WAL segments, in megabytes\n"));
printf(_(" -?, --help show this help, then exit\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_rewind/pg_rewind.c b/src/bin/pg_rewind/pg_rewind.c
index a0dfda701e..7ccde5c87f 100644
--- a/src/bin/pg_rewind/pg_rewind.c
+++ b/src/bin/pg_rewind/pg_rewind.c
@@ -78,7 +78,7 @@ usage(const char *progname)
printf(_(" --debug write a lot of debug messages\n"));
printf(_(" -V, --version output version information, then exit\n"));
printf(_(" -?, --help show this help, then exit\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_upgrade/option.c b/src/bin/pg_upgrade/option.c
index cf4151758f..ab5e2d6a30 100644
--- a/src/bin/pg_upgrade/option.c
+++ b/src/bin/pg_upgrade/option.c
@@ -336,7 +336,7 @@ usage(void)
" C:\\> set PGBINNEW=newCluster/bin\n"
" C:\\> pg_upgrade\n"));
#endif
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_verify_checksums/pg_verify_checksums.c b/src/bin/pg_verify_checksums/pg_verify_checksums.c
index cc6ebb9df0..511262ab5f 100644
--- a/src/bin/pg_verify_checksums/pg_verify_checksums.c
+++ b/src/bin/pg_verify_checksums/pg_verify_checksums.c
@@ -47,7 +47,7 @@ usage(void)
printf(_(" -?, --help show this help, then exit\n"));
printf(_("\nIf no data directory (DATADIR) is specified, "
"the environment variable PGDATA\nis used.\n\n"));
- printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
/*
diff --git a/src/bin/pgbench/pgbench.c b/src/bin/pgbench/pgbench.c
index 49670768f5..b5c75ce1c6 100644
--- a/src/bin/pgbench/pgbench.c
+++ b/src/bin/pgbench/pgbench.c
@@ -690,7 +690,7 @@ usage(void)
" -V, --version output version information, then exit\n"
" -?, --help show this help, then exit\n"
"\n"
- "Report bugs to <pgsql-bugs@postgresql.org>.\n",
+ "Report bugs to <pgsql-bugs@lists.postgresql.org>.\n",
progname, progname);
}
diff --git a/src/bin/psql/help.c b/src/bin/psql/help.c
index a403431760..7c6fa2c590 100644
--- a/src/bin/psql/help.c
+++ b/src/bin/psql/help.c
@@ -144,7 +144,7 @@ usage(unsigned short int pager)
fprintf(output, _("\nFor more information, type \"\\?\" (for internal commands) or \"\\help\" (for SQL\n"
"commands) from within psql, or consult the psql section in the PostgreSQL\n"
"documentation.\n\n"));
- fprintf(output, _("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+ fprintf(output, _("Report bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
ClosePager(output);
}
diff --git a/src/bin/scripts/clusterdb.c b/src/bin/scripts/clusterdb.c
index 41dd2a5758..cc6efce596 100644
--- a/src/bin/scripts/clusterdb.c
+++ b/src/bin/scripts/clusterdb.c
@@ -290,5 +290,5 @@ help(const char *progname)
printf(_(" -W, --password force password prompt\n"));
printf(_(" --maintenance-db=DBNAME alternate maintenance database\n"));
printf(_("\nRead the description of the SQL command CLUSTER for details.\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/createdb.c b/src/bin/scripts/createdb.c
index c765b8ec66..b40eea4365 100644
--- a/src/bin/scripts/createdb.c
+++ b/src/bin/scripts/createdb.c
@@ -270,5 +270,5 @@ help(const char *progname)
printf(_(" -W, --password force password prompt\n"));
printf(_(" --maintenance-db=DBNAME alternate maintenance database\n"));
printf(_("\nBy default, a database with the same name as the current user is created.\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/createuser.c b/src/bin/scripts/createuser.c
index 8098f482bb..ae546c70fb 100644
--- a/src/bin/scripts/createuser.c
+++ b/src/bin/scripts/createuser.c
@@ -370,5 +370,5 @@ help(const char *progname)
printf(_(" -U, --username=USERNAME user name to connect as (not the one to create)\n"));
printf(_(" -w, --no-password never prompt for password\n"));
printf(_(" -W, --password force password prompt\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/dropdb.c b/src/bin/scripts/dropdb.c
index 45680dde27..df7823df99 100644
--- a/src/bin/scripts/dropdb.c
+++ b/src/bin/scripts/dropdb.c
@@ -168,5 +168,5 @@ help(const char *progname)
printf(_(" -w, --no-password never prompt for password\n"));
printf(_(" -W, --password force password prompt\n"));
printf(_(" --maintenance-db=DBNAME alternate maintenance database\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/dropuser.c b/src/bin/scripts/dropuser.c
index 2b6f721844..62971131c5 100644
--- a/src/bin/scripts/dropuser.c
+++ b/src/bin/scripts/dropuser.c
@@ -173,5 +173,5 @@ help(const char *progname)
printf(_(" -U, --username=USERNAME user name to connect as (not the one to drop)\n"));
printf(_(" -w, --no-password never prompt for password\n"));
printf(_(" -W, --password force password prompt\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/pg_isready.c b/src/bin/scripts/pg_isready.c
index 467c22891c..26b21dcbb0 100644
--- a/src/bin/scripts/pg_isready.c
+++ b/src/bin/scripts/pg_isready.c
@@ -233,5 +233,5 @@ help(const char *progname)
printf(_(" -p, --port=PORT database server port\n"));
printf(_(" -t, --timeout=SECS seconds to wait when attempting connection, 0 disables (default: %s)\n"), DEFAULT_CONNECT_TIMEOUT);
printf(_(" -U, --username=USERNAME user name to connect as\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/reindexdb.c b/src/bin/scripts/reindexdb.c
index 69fb2f8fd2..1cd1ccc951 100644
--- a/src/bin/scripts/reindexdb.c
+++ b/src/bin/scripts/reindexdb.c
@@ -421,5 +421,5 @@ help(const char *progname)
printf(_(" -W, --password force password prompt\n"));
printf(_(" --maintenance-db=DBNAME alternate maintenance database\n"));
printf(_("\nRead the description of the SQL command REINDEX for details.\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/scripts/vacuumdb.c b/src/bin/scripts/vacuumdb.c
index 127b75e0b4..ec7d0a326a 100644
--- a/src/bin/scripts/vacuumdb.c
+++ b/src/bin/scripts/vacuumdb.c
@@ -1093,5 +1093,5 @@ help(const char *progname)
printf(_(" -W, --password force password prompt\n"));
printf(_(" --maintenance-db=DBNAME alternate maintenance database\n"));
printf(_("\nRead the description of the SQL command VACUUM for details.\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
diff --git a/src/bin/pg_archivecleanup/pg_archivecleanup.c b/src/bin/pg_archivecleanup/pg_archivecleanup.c
index c62478dbd6..4c3a2de045 100644
--- a/src/bin/pg_archivecleanup/pg_archivecleanup.c
+++ b/src/bin/pg_archivecleanup/pg_archivecleanup.c
@@ -43,7 +43,7 @@ char exclusiveCleanupFileName[MAXFNAMELEN]; /* the oldest file we want
* accessible directory. If you want to make other assumptions,
* such as using a vendor-specific archive and access API, these
* routines are the ones you'll need to change. You're
* encouraged to submit any changes to pgsql-hackers@postgresql.org
* or personally to the current maintainer. Those changes may be
* folded in to later versions of this program.
*/
@@ -273,7 +273,7 @@ usage(void)
"Or for use as a standalone archive cleaner:\n"
"e.g.\n"
" pg_archivecleanup /mnt/server/archiverdir 000000010000000000000010.00000020.backup\n"));
- printf(_("\nReport bugs to <pgsql-bugs@postgresql.org>.\n"));
+ printf(_("\nReport bugs to <pgsql-bugs@lists.postgresql.org>.\n"));
}
/*------------ MAIN ----------------------------------------*/
@@ -43,7 +43,7 @@ char exclusiveCleanupFileName[MAXFNAMELEN]; /* the oldest file we want
* such as using a vendor-specific archive and access API, these
* routines are the ones you'll need to change. You're
- * encouraged to submit any changes to pgsql-hackers@postgresql.org
+ * encouraged to submit any changes to pgsql-hackers@lists.postgresql.org
* or personally to the current maintainer. Those changes may be
* folded in to later versions of this program.